==> packagesearch_2.5.tar.gz: packagesearch-2.5/translations/debtagsplugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>ChoosenTagsDisplay</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="34"/>
        <source>Show the packages with all of the tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="44"/>
        <source>Exclude packages with any of the tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebtagsSettingsWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="41"/>
        <source>Facets Shown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="65"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="72"/>
        <source>&lt;&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="89"/>
        <source>Facets Hidden</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::DebtagsPlugin</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugin.cpp" line="208"/>
        <source>Performing tag search on package database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::DebtagsPluginContainer</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.cpp" line="219"/>
        <source>Tag Database Not Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.cpp" line="228"/>
        <source>&lt;p&gt;The tag database is not available and the debtags plugin was disabled!&lt;/p&gt;&lt;p&gt;You must execute &lt;tt&gt;&lt;b&gt;debtags update&lt;/b&gt;&lt;/tt&gt; as root on the commandline to download the database. If debtags is not on your system you can install it via &lt;tt&gt;&lt;b&gt;apt-get install debtags&lt;/b&gt;&lt;/tt&gt;&lt;br&gt;Afterwards you can enable the debtags plugin via the Packagesearch menu -&gt; Control Plugins.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.h" line="94"/>
        <source>Debtags Plugins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::RelatedPlugin</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="57"/>
        <source>Similar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="67"/>
        <source>Plugin for searching packages similar to another package.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="108"/>
        <source>Similar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="172"/>
        <source>Searching for similar packages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NTagModel::SelectedTagsView</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="42"/>
        <source>deselect a tag by double-clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="44"/>
        <source>This list displays the tags currently searched for. To remove a tag double-click it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="73"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="78"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NTagModel::UnselectedTagsView</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="118"/>
        <source>select a tag by double-clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="121"/>
        <source>This list shows the tags that can be searched for. The tags are organised in a tree beneath their facets (groups of tags). To search for packages with a tag, double-click the tag. Multiple tags can be selected like this. Facets cannot be selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="160"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="165"/>
        <source>Collapse all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="166"/>
        <source>Expand all</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NWidgets::SelectionInputAndDisplay</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectioninputanddisplay.cpp" line="48"/>
        <source>filter string to filter tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectioninputanddisplay.cpp" line="49"/>
        <source>Filters the tag names by the string in realtime.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RelatedFeedbackWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="25"/>
        <source>Search packages similar to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="40"/>
        <source>displays the package to search related packages for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="43"/>
        <source>This displays the package for which you want to search related packages for. Enter the package under the &quot;Related&quot; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="53"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RelatedInput</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="13"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="25"/>
        <source>Similar to package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="50"/>
        <source>Maximum Distance:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="57"/>
        <source>Maximum number of tags the packages may differ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="60"/>
        <source>This is the maximum number of tags in which the packages may differ from the given one. &lt;br&gt;
Or more formal: &lt;br&gt;
|(A union B) difference (A intersect B)| &amp;lt;= MaxDistance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="101"/>
        <source>Clear realated search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="104"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagChooserWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="16"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="28"/>
        <source>Show packages with these tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="35"/>
        <source>Check this to be able to exclude some tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="38"/>
        <source>Check this if you want to exclude some tags. If you check it, a list of tags will be shown. There you can select which to exclude.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="41"/>
        <source>Exclude Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="48"/>
        <source>but not these tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> packagesearch_2.6.tar.gz: packagesearch-2.6/translations/debtagsplugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>ChoosenTagsDisplay</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="34"/>
        <source>Show the packages with all of the tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/choosentagsdisplay.ui" line="44"/>
        <source>Exclude packages with any of the tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebtagsSettingsWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="41"/>
        <source>Facets Shown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="65"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="72"/>
        <source>&lt;&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagssettingswidget.ui" line="89"/>
        <source>Facets Hidden</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::DebtagsPlugin</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugin.cpp" line="168"/>
        <source>Performing tag search on package database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::DebtagsPluginContainer</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.h" line="84"/>
        <source>Debtags Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.cpp" line="115"/>
        <source>No vocabulary available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/debtagsplugincontainer.cpp" line="116"/>
        <source>&lt;p&gt;The vocabulary is not available. This should not happen. Please reinstall &lt;tt&gt;debtags&lt;/tt&gt; or check your /var/lib/debtags/vocabulary file manually.&lt;/p&gt;The debtags plugin will be disabled for now, you can re-enable it via the Packagesearch menu -&gt; Control Plugins.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::RelatedPlugin</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="60"/>
        <source>Similar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="65"/>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="70"/>
        <source>Plugin for searching packages similar to another package.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="109"/>
        <source>Similar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedplugin.cpp" line="188"/>
        <source>Searching for similar packages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NTagModel::SelectedTagsView</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="41"/>
        <source>deselect a tag by double-clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="42"/>
        <source>This list displays the tags currently searched for. To remove a tag double-click it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="72"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectedtagsview.cpp" line="77"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NTagModel::UnselectedTagsView</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="116"/>
        <source>select a tag by double-clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="117"/>
        <source>This list shows the tags that can be searched for. The tags are organised in a tree beneath their facets (groups of tags). To search for packages with a tag, double-click the tag. Multiple tags can be selected like this. Facets cannot be selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="158"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="163"/>
        <source>Collapse all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/unselectedtagsview.cpp" line="164"/>
        <source>Expand all</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NWidgets::SelectionInputAndDisplay</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectioninputanddisplay.cpp" line="48"/>
        <source>filter string to filter tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/selectioninputanddisplay.cpp" line="49"/>
        <source>Filters the tag names by the string in realtime.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RelatedFeedbackWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="13"/>
        <source>Form2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="25"/>
        <source>Search packages similar to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="40"/>
        <source>displays the package to search related packages for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="43"/>
        <source>This displays the package for which you want to search related packages for. Enter the package under the &quot;Related&quot; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedfeedbackwidget.ui" line="53"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RelatedInput</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="14"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="26"/>
        <source>Similar to package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="51"/>
        <source>Result packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="58"/>
        <source>Number of result packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="61"/>
        <source>Defines the number of the most similar packages which will be displayed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="103"/>
        <source>Clear realated search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/relatedinput.ui" line="106"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagChooserWidget</name>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="16"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="28"/>
        <source>Show packages with these tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="35"/>
        <source>Check this to be able to exclude some tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="38"/>
        <source>Check this if you want to exclude some tags. If you check it, a list of tags will be shown. There you can select which to exclude.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="41"/>
        <source>Exclude Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/debtagsplugin/tagchooserwidget.ui" line="48"/>
        <source>but not these tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
